@@ -1,5 +1,6 @@
 import argparse
 from argparse import ArgumentParser
+from textwrap import dedent
 from typing import Any, Mapping, List
 from . import docker, native, aws_batch
 from .. import config
@@ -57,10 +58,14 @@ def register_flags(parser: ArgumentParser, runners: List, default: Any) -> None:
     """
     Register runner selection flags on the given ArgumentParser instance.
     """
+    runner_selection = parser.add_argument_group(
+        "runner selection options",
+        "Select the method for running a Nextstrain computing environment, if the\n"
+        "default is not suitable.")
 
     # We use a different flag for each runner for a simpler UX, but only one
     # runner may be selected from the group.
-    flags = parser.add_mutually_exclusive_group()
+    flags = runner_selection.add_mutually_exclusive_group()
 
     # The selected runner is stored in __runner__ (a la __command__).  The
     # run() function below calls __runner__.
@@ -100,7 +105,22 @@ def register_arguments(parser: ArgumentParser, runners: List, exec: List) -> Non
         "development options",
         "These should generally be unnecessary unless you're developing Nextstrain.")
 
+    # Image to use; shared by Docker and AWS Batch runners
+    development.add_argument(
+        "--image",
+        help    = "Container image name to use for the Nextstrain computing environment",
+        metavar = "<image>",
+        default = docker.DEFAULT_IMAGE)
+
     # Program to execute
+    #
+    # XXX TODO: We could make this nargs = "*" to accept more than one arg and
+    # thus provide a way to override default_exec_args.  This would resolve
+    # some weirdness below re: the interplay of default exec args, the
+    # Ellipsis, and extra_exec_args.  However, it would require --exec's last
+    # value is followed by either another option or "--" to separate the --exec
+    # values from other positional arguments like the build workdir.
+    #   -trs, 21 May 2020
     development.add_argument(
         "--exec",
         help    = "Program to run inside the build environment",
@@ -127,7 +147,7 @@ def register_arguments(parser: ArgumentParser, runners: List, exec: List) -> Non
         runner.register_arguments(parser)
 
 
-def run(opts: Options, working_volume: NamedVolume = None, extra_env: Mapping = {}) -> int:
+def run(opts: Options, working_volume: NamedVolume = None, extra_env: Mapping = {}, cpus: int = None, memory: int = None) -> int:
     """
     Inspect the given options object and call the selected runner's run()
     function with appropriate arguments.
@@ -144,7 +164,12 @@ def run(opts: Options, working_volume: NamedVolume = None, extra_env: Mapping =
         )
     ]
 
-    return opts.__runner__.run(opts, argv, working_volume = working_volume, extra_env = extra_env)
+    if opts.image != docker.DEFAULT_IMAGE and opts.__runner__ is native:
+        warn(dedent("""
+            Warning: The specified --image=%s option is not used by --native.
+            """ % opts.image))
+
+    return opts.__runner__.run(opts, argv, working_volume = working_volume, extra_env = extra_env, cpus = cpus, memory = memory)
 
 
 def replace_ellipsis(items, elided_items):
