@@ -5,7 +5,7 @@ import site
 import subprocess
 import sys
 from types import ModuleType
-from typing import Mapping, List
+from typing import Mapping, List, Tuple
 from pathlib import Path
 from pkg_resources import parse_version
 from shutil import which
@@ -71,8 +71,11 @@ def check_for_new_version():
         print()
         print("Upgrade by running:")
         print()
-        print("    " + python + " -m pip install --user --upgrade nextstrain-cli" if installed_into_user_site else \
-              "    " + python + " -m pip install --upgrade nextstrain-cli")
+        if "/pipx/venvs/nextstrain-cli/" in python:
+            print("    pipx upgrade nextstrain-cli")
+        else:
+            print("    " + python + " -m pip install --user --upgrade nextstrain-cli" if installed_into_user_site else \
+                  "    " + python + " -m pip install --upgrade nextstrain-cli")
         print()
     else:
         print("nextstrain-cli is up to date!")
@@ -105,7 +108,7 @@ def capture_output(argv):
     lines.
 
     This wrapper around subprocess.run() exists because its own capture_output
-    parameter wasn't added until Python 3.7 and we aim for compat with 3.5.
+    parameter wasn't added until Python 3.7 and we aim for compat with 3.6.
     When we bump our minimum Python version, we can remove this wrapper.
     """
     result = subprocess.run(
@@ -213,3 +216,97 @@ def resolve_path(path: Path) -> Path:
         return path.resolve(strict = True) # type: ignore
     else:
         return path.resolve()
+
+
+def byte_quantity(quantity: str) -> int:
+    """
+    Parses a string *quantity* consisting of a number, optional whitespace, and
+    a unit of bytes.
+
+    Returns the number of bytes in *quantity*, as an integer.
+
+    Supported units:
+
+    * ``b`` (bytes)
+    * ``kb`` (kilobytes)
+    * ``mb`` (megabytes)
+    * ``gb`` (gigabytes)
+    * ``kib`` (kibibytes)
+    * ``mib`` (mebibytes)
+    * ``gib`` (gibibytes)
+
+    Units are not case sensitive.  If no unit is given, bytes is assumed.
+
+    Raises a :py:class:`ValueError` if *quantity* is not parseable.
+
+    >>> byte_quantity("2Kb")
+    2000
+    >>> byte_quantity("2 kib")
+    2048
+    >>> byte_quantity("1.5GB")
+    1500000000
+    >>> byte_quantity("1024")
+    1024
+    >>> byte_quantity("hello mb")
+    Traceback (most recent call last):
+        ...
+    ValueError: Unparseable byte quantity value: 'hello'
+    """
+    match = re.search(r"""
+        ^
+        # The numeric value.  We rely on float() to parse this, so don't
+        # restrict it here.
+        (\S+?)
+
+        \s*
+
+        # The optional unit.
+        ( [kmg]b
+        | [kmg]ib
+        | b
+        )?
+        $
+        """, quantity.strip(), re.VERBOSE | re.IGNORECASE)
+
+    if not match:
+        raise ValueError("Unrecognized byte quantity: %s" % repr(quantity))
+
+    value_str, units = match.groups()
+
+    try:
+        value = float(value_str)
+    except ValueError:
+        raise ValueError("Unparseable byte quantity value: %s" % repr(value_str)) from None
+
+    if not units:
+        units = "b"
+
+    unit_factor = {
+        'b': 1,
+        'kb': 1000,
+        'mb': 1000**2,
+        'gb': 1000**3,
+        'kib': 1024,
+        'mib': 1024**2,
+        'gib': 1024**3,
+    }
+
+    return int(value * unit_factor[units.lower()])
+
+
+def split_image_name(name: str) -> Tuple[str, str]:
+    """
+    Split the Docker image *name* into a (repository, tag) tuple.
+
+    >>> split_image_name("nextstrain/base:build-20200424T101900Z")
+    ('nextstrain/base', 'build-20200424T101900Z')
+
+    >>> split_image_name("nextstrain/base")
+    ('nextstrain/base', 'latest')
+    """
+    if ":" in name:
+        repository, tag = name.split(":", maxsplit = 2)
+    else:
+        repository, tag = name, "latest"
+
+    return (repository, tag)
